@@ -93,6 +93,7 @@ pub trait ResourceExt {
     fn labels(self, labels: impl IntoIterator<Item = (impl ToString, impl ToString)>) -> Self;
     #[must_use]
     fn with_resource_version(self, resource_version: String) -> Self;
+    fn managed_fields(&self) -> Option<&[metav1::ManagedFieldsEntry]>;
 }
 
 impl<T> ResourceExt for T
@@ -122,4 +123,8 @@ where
         self.meta_mut().resource_version = Some(resource_version);
         self
     }
+
+    fn managed_fields(&self) -> Option<&[metav1::ManagedFieldsEntry]> {
+        self.meta().managed_fields.as_deref()
+    }
 }
