@@ -6,12 +6,12 @@
 use super::*;
 
 pub trait RoleRefExt: Sized {
-    fn new<T: kube::Resource<DynamicType = ()>, S: ToString>(name: S) -> Self;
+    fn new<T: kube::Resource<DynamicType = ()>>(k: &T) -> Self;
 }
 
 impl RoleRefExt for rbacv1::RoleRef {
-    fn new<T: kube::Resource<DynamicType = ()>, S: ToString>(name: S) -> Self {
-        let name = name.to_string();
+    fn new<T: kube::Resource<DynamicType = ()>>(k: &T) -> Self {
+        let name = k.name();
         let api_group = T::group(&()).to_string();
         let kind = T::kind(&()).to_string();
         Self {
