@@ -351,12 +351,11 @@ impl super::Kubectl {
         name: &str,
         mut update_fn: impl FnMut(&mut BTreeMap<String, String>),
     ) -> kube::Result<()> {
-        Self::entry(
+        Self::update_with_default(
             self.configmaps(None),
             name,
-            Self::MAX_RETRIES,
-            |cm| update_fn(cm.data.get_or_insert_with(BTreeMap::default)),
-            Some(|| corev1::ConfigMap::new(name)),
+            |cm| update_fn(cm.data_mut()),
+            || corev1::ConfigMap::new(name),
         )
         .await
     }
